@@ -21,14 +21,14 @@
  *           Fax: +49 7123 / 14892
  *
  *
- *  $Id: dbdimp.h,v 1.1.1.1.2.1 1998/12/22 15:01:32 joe Exp $
+ *  $Id: dbdimp.h 1.1 Tue, 30 Sep 1997 01:28:08 +0200 joe $
  */
 
 /*
  *  Header files we use
  */
+#define NEED_DBIXS_VERSION 9
 #include <DBIXS.h>  /* installed by the DBI module                        */
-
 #include "myMsql.h"
 
 
@@ -53,9 +53,7 @@ enum errMsgs {
     JW_ERR_NO_RESULT,
     JW_ERR_NOT_IMPLEMENTED,
     JW_ERR_ILLEGAL_PARAM_NUM,
-    JW_ERR_MEM,
-    JW_ERR_LIST_INDEX,
-    JW_ERR_SEQUENCE
+    JW_ERR_MEM
 };
 
 
@@ -66,15 +64,12 @@ enum av_attribs {
     AV_ATTRIB_NAME = 0,
     AV_ATTRIB_TABLE,
     AV_ATTRIB_TYPE,
-    AV_ATTRIB_SQL_TYPE,
     AV_ATTRIB_IS_PRI_KEY,
     AV_ATTRIB_IS_NOT_NULL,
     AV_ATTRIB_NULLABLE,
     AV_ATTRIB_LENGTH,
     AV_ATTRIB_IS_NUM,
     AV_ATTRIB_TYPE_NAME,
-    AV_ATTRIB_PRECISION,
-    AV_ATTRIB_SCALE,
 #ifdef DBD_MYSQL
     AV_ATTRIB_MAX_LENGTH,
     AV_ATTRIB_IS_KEY,
@@ -121,8 +116,6 @@ struct imp_dbh_st {
 };
 
 
-
-
 /*
  *  The bind_param method internally uses this structure for storing
  *  parameters.
@@ -133,7 +126,6 @@ typedef struct imp_sth_ph_st {
 } imp_sth_ph_t;
 
 
-
 /*
  *  Finally our part of the statement handle. We receive the handle as
  *  an "SV*", say "dbh", and receive a pointer to the structure below
@@ -157,9 +149,6 @@ struct imp_sth_st {
     int   insertid;       /* ID of auto insert                      */
     imp_sth_ph_t* params; /* Pointer to parameter array             */
     AV* av_attr[AV_ATTRIB_LAST];/*  For caching array attributes        */
-    int   use_mysql_use_result;  /*  TRUE if execute should use     */
-                          /* mysql_use_result rather than           */
-                          /* mysql_store_result */
 };
 
 
@@ -168,15 +157,12 @@ struct imp_sth_st {
  *
  * These defines avoid name clashes for multiple statically linked DBD's	*/
 #ifdef DBD_MYSQL
-#define MyLogin			mysql_dr_login
-#define MyConnect		mysql_dr_connect
-#define dbd_init		mysql_dr_init
+#define dbd_init		mysql_init
 #define dbd_db_login		mysql_db_login
 #define dbd_db_do		mysql_db_do
 #define dbd_db_commit		mysql_db_commit
 #define dbd_db_rollback		mysql_db_rollback
 #define dbd_db_disconnect	mysql_db_disconnect
-#define dbd_discon_all		mysql_db_discon_all
 #define dbd_db_destroy		mysql_db_destroy
 #define dbd_db_STORE_attrib	mysql_db_STORE_attrib
 #define dbd_db_FETCH_attrib	mysql_db_FETCH_attrib
@@ -189,59 +175,16 @@ struct imp_sth_st {
 #define dbd_st_blob_read	mysql_st_blob_read
 #define dbd_st_STORE_attrib	mysql_st_STORE_attrib
 #define dbd_st_FETCH_attrib	mysql_st_FETCH_attrib
-#define dbd_st_FETCH_internal	mysql_st_FETCH_internal
 #define dbd_describe		mysql_describe
 #define dbd_bind_ph		mysql_bind_ph
-#define BindParam		mysql_st_bind_param
 #define dbd_st_internal_execute mysql_st_internal_execute
-#define mymsql_constant         mysql_constant
-#define do_warn			mysql_dr_warn
-#define do_error		mysql_dr_error
-#define dbd_db_type_info_all    mysql_db_type_info_all
-#define dbd_db_quote            mysql_db_quote
-#elif defined(DBD_MSQL1)
-#define MyLogin			msql1_dr_login
-#define MyConnect		msql1_dr_connect
-#define dbd_init		msql1_dr_init
-#define dbd_db_login		msql1_db_login
-#define dbd_db_do		msql1_db_do
-#define dbd_db_commit		msql1_db_commit
-#define dbd_db_rollback		msql1_db_rollback
-#define dbd_db_disconnect	msql1_db_disconnect
-#define dbd_discon_all		msql1_db_discon_all
-#define dbd_db_destroy		msql1_db_destroy
-#define dbd_db_STORE_attrib	msql1_db_STORE_attrib
-#define dbd_db_FETCH_attrib	msql1_db_FETCH_attrib
-#define dbd_st_prepare		msql1_st_prepare
-#define dbd_st_rows		msql1_st_rows
-#define dbd_st_execute		msql1_st_execute
-#define dbd_st_fetch		msql1_st_fetch
-#define dbd_st_finish		msql1_st_finish
-#define dbd_st_destroy		msql1_st_destroy
-#define dbd_st_blob_read	msql1_st_blob_read
-#define dbd_st_STORE_attrib	msql1_st_STORE_attrib
-#define dbd_st_FETCH_attrib	msql1_st_FETCH_attrib
-#define dbd_st_FETCH_internal	msql1_st_FETCH_internal
-#define dbd_describe		msql1_describe
-#define dbd_bind_ph		msql1_bind_ph
-#define BindParam		msql1_st_bind_param
-#define dbd_st_internal_execute msql1_st_internal_execute
-#define mymsql_constant         msql1_constant
-#define do_warn			msql1_dr_warn
-#define do_error		msql1_dr_error
-#define dbd_dr_types            msql1_dr_types
-#define dbd_db_type_info_all    msql1_db_type_info_all
-#define dbd_db_quote            msql1_db_quote
 #else
-#define MyLogin			msql_dr_login
-#define MyConnect		msql_dr_connect
-#define dbd_init		msql_dr_init
+#define dbd_init		msql_init
 #define dbd_db_login		msql_db_login
 #define dbd_db_do		msql_db_do
 #define dbd_db_commit		msql_db_commit
 #define dbd_db_rollback		msql_db_rollback
 #define dbd_db_disconnect	msql_db_disconnect
-#define dbd_discon_all		msql_db_discon_all
 #define dbd_db_destroy		msql_db_destroy
 #define dbd_db_STORE_attrib	msql_db_STORE_attrib
 #define dbd_db_FETCH_attrib	msql_db_FETCH_attrib
@@ -254,17 +197,9 @@ struct imp_sth_st {
 #define dbd_st_blob_read	msql_st_blob_read
 #define dbd_st_STORE_attrib	msql_st_STORE_attrib
 #define dbd_st_FETCH_attrib	msql_st_FETCH_attrib
-#define dbd_st_FETCH_internal	msql_st_FETCH_internal
 #define dbd_describe		msql_describe
 #define dbd_bind_ph		msql_bind_ph
-#define BindParam		msql_st_bind_param
 #define dbd_st_internal_execute msql_st_internal_execute
-#define mymsql_constant         msql_constant
-#define do_warn			msql_dr_warn
-#define do_error		msql_dr_error
-#define dbd_dr_types            msql_dr_types
-#define dbd_db_type_info_all    msql_db_type_info_all
-#define dbd_db_quote            msql_db_quote
 #endif
 
 #include <dbd_xsh.h>
@@ -273,31 +208,5 @@ SV	*dbd_db_fieldlist _((result_t res));
 
 void    dbd_preparse _((imp_sth_t *imp_sth, SV *statement));
 int dbd_st_internal_execute(SV*, SV*, SV*, int, imp_sth_ph_t*, result_t*,
-			    dbh_t, int);
-AV* dbd_db_type_info_all _((SV* dbh, imp_dbh_t* imp_dbh));
-SV* dbd_db_quote(SV*, SV*, SV*);
+			    dbh_t);
 
-
-typedef struct {
-    char* typeName;
-    int dataType;
-    int precision;
-    char* literalPrefix;
-    char* literalSuffix;
-    char* createParams;
-    int nullable;
-    int caseSensitive;
-    int searchable;
-    int unsignedAttribute;
-    int money;
-    int autoIncrement;
-    char* localTypeName;
-    int minimumScale;
-    int maximumScale;
-    AV* av;
-} mymsql_type;
-
-extern mymsql_type dbd_dr_types[];
-
-
-extern int MysqlReconnect(SV*);
